# docxstache 2.0

A purer implementation of `pystache` for word documents. 

Start with a template...
![](docs/before.png)

Add a little json...

![](docs/json.png)

Get beautiful results...
![](docs/after.png)

# Usage

`python app /path/to/file.docx /path/to/file.json /path/to/newfile.docx`

# License 

MIT